@@ -17,7 +17,9 @@
 
 import ctypes
 
-from ctypes import windll, wintypes
+from ctypes import wintypes
+
+windll = ctypes.LibraryLoader(ctypes.WinDLL)
 
 
 WM_CREATE = 0x0001
@@ -345,7 +347,8 @@ try:
     ChangeWindowMessageFilterEx.errcheck = _err
 
 except KeyError:
-    def ChangeWindowMessageFilterEx(hWnd, message, action, pCHangeFilterStruct):
+    def ChangeWindowMessageFilterEx(
+            hWnd, message, action, pCHangeFilterStruct):
         """A dummy implementation of ``ChangeWindowMessageFilterEx`` always
         returning ``TRUE``.
 
